@@ -1,7 +1,8 @@
-from .bscscan import BscScan
+from .client import BscScan
 from .modules.accounts import Accounts as accounts
 from .modules.blocks import Blocks as blocks
 from .modules.contracts import Contracts as contracts
+from .modules.logs import Logs as logs
 from .modules.proxy import Proxy as proxy
 from .modules.stats import Stats as stats
 from .modules.tokens import Tokens as tokens
